from setuptools import setup, find_packages

setup(
	name='pypck_dummy',
	version='0.0.10',
	description='This is a test.',
	author='',
	author_email='',
	url='https://gitub.com/...',
	packages=find_packages(),
	install_requires=[]
)
