from .todays_practice import main

def practice_reaction().
	"""xxx"""

	prac = main()
	
	if prac in ["mostly talk", "aerobic"]:
		print("OOOOOH NOOOOOO!!")
	
	else:
		print(LET'S GOOOOOOOOOOO!!)


if __name__ == "__main__":
	practice_reaction()
